@@ -338,14 +338,15 @@ sub __autoincrement_column {
 sub __primary_key_autoincrement_constraint {
     # provide "primary_key_autoincrement_constraint" only if also "first_col_is_autoincrement" is available
     my ( $sf ) = @_;
-    if ( $sf->{i}{driver} eq 'SQLite' ) {
+    my $driver = $sf->{i}{driver};
+    if ( $driver eq 'SQLite' ) {
         return "INTEGER PRIMARY KEY";
     }
-    if ( $sf->{i}{driver} =~ /^(?:mysql|MariaDB)\z/ ) {
+    if ( $driver =~ /^(?:mysql|MariaDB)\z/ ) {
         return "INT NOT NULL AUTO_INCREMENT PRIMARY KEY";
         # mysql: NOT NULL added automatically with AUTO_INCREMENT
     }
-    if ( $sf->{i}{driver} eq 'Pg' ) {
+    if ( $driver eq 'Pg' ) {
         my ( $pg_version ) = $sf->{d}{dbh}->selectrow_array( "SELECT version()" );
         if ( $pg_version =~ /^\S+\s+([0-9]+)(?:\.[0-9]+)*\s/ && $1 >= 10 ) {
             # since PostgreSQL version 10
@@ -355,7 +356,7 @@ sub __primary_key_autoincrement_constraint {
             return "SERIAL PRIMARY KEY";
         }
     }
-    if ( $sf->{i}{driver} eq 'Firebird' ) {
+    if ( $driver eq 'Firebird' ) {
         my ( $firebird_version ) = $sf->{d}{dbh}->selectrow_array( "SELECT RDB\$GET_CONTEXT('SYSTEM', 'ENGINE_VERSION') FROM RDB\$DATABASE" );
         my $firebird_major_version = $firebird_version =~ s/^(\d+).+\z/$1/r;
         if ( $firebird_major_version >= 4 ) {
@@ -365,9 +366,15 @@ sub __primary_key_autoincrement_constraint {
             return "INT GENERATED BY DEFAULT AS IDENTITY PRIMARY KEY";
         }
     }
-    if ( $sf->{i}{driver} eq 'DB2' ) {
+    if ( $driver eq 'DB2' ) {
         return "INT NOT NULL GENERATED ALWAYS AS IDENTITY PRIMARY KEY";
     }
+    if ( $driver eq 'Oracle' ) {
+        my $ora_server_version = $sf->{d}{dbh}->func( 'ora_server_version' );
+        if ( $ora_server_version->[0] >= 12 ) {
+            return "NUMBER GENERATED ALWAYS as IDENTITY";   # Oracle 12c or greater
+        }
+    }
 }
 
 
