@@ -5,8 +5,6 @@ use warnings;
 use strict;
 use 5.014;
 
-use File::Basename qw( basename );
-
 use DBI qw();
 
 use Term::Choose::Util qw();
@@ -56,8 +54,8 @@ sub read_attributes {
 sub set_attributes {
     my ( $sf ) = @_;
     return [
-        { name => 'LongTruncOk',  default => 0, values => [ 0, 1 ] },
-        { name => 'ChopBlanks',   default => 0, values => [ 0, 1 ] },
+        { name => 'LongTruncOk', default => 0, values => [ 0, 1 ] },
+        { name => 'ChopBlanks',  default => 0, values => [ 0, 1 ] },
     ];
 }
 
@@ -74,7 +72,7 @@ sub get_db_handle {
     my $cred = App::DBBrowser::Credentials->new( $sf->{i}, $sf->{o} );
     my $settings = { login_data => $login_data, env_var_yes => $env_var_yes };
     my $dsn;
-    my $show_sofar = 'DB '. basename( $db );
+    my $show_sofar = 'DB '. $db;
     # DBD::DB2 - Data Source Names:
     # Cataloged database connections can be done by passing the database alias, username, and password as parameters.
     # This method does not allow entering the host name, port number, etc but will require you to catalog the database
